==> fuse-ui-codemirror-1.5.3.tgz: package/es/index.js <==
import { __spreadArray, __assign } from 'tslib';
import { ref, watch, onMounted, defineComponent } from '@vue/composition-api';
import _ from 'lodash';
import { EditorState, basicSetup } from '@codemirror/basic-setup';
import { EditorView, keymap } from '@codemirror/view';
import { cursorCharLeft, indentWithTab, standardKeymap } from '@codemirror/commands';
import { xml } from '@codemirror/lang-xml';
import { json } from '@codemirror/lang-json';

function useCodemirror(props, context, parentRef, extensions) {
    if (extensions === void 0) { extensions = []; }
    var innerValue = ref(props.value);
    watch(function () { return props.value; }, function () {
        if (!_.isEqual(props.value, innerValue.value)) {
            if (props.value) {
                innerValue.value = props.value;
            }
        }
    });
    watch(innerValue, function () {
        if (!_.isEqual(props.value, innerValue.value)) {
            context.emit('input', innerValue.value);
        }
    });
    var editorViewRef = ref(null);
    function initEditor() {
        var changeHandler = EditorView.updateListener.of(function (v) {
            if (v.docChanged) {
                innerValue.value = v.state.doc.toString();
            }
        });
        var minHeightStyle = EditorView.theme({
            '.cm-content, .cm-gutter': { minHeight: props.minHeight },
            '&': { border: '1px solid rgba(0, 0, 0, 0.15)' },
            '&.cm-focused': { border: '1px solid rgba(0, 0, 0, 0.24)', outline: 'none' }
        });
        var state = EditorState.create({
            doc: innerValue.value,
            extensions: __spreadArray(__spreadArray([
                basicSetup,
                EditorState.tabSize.of(2),
                keymap.of(__spreadArray([indentWithTab], standardKeymap)),
                changeHandler
            ], extensions), [
                minHeightStyle
            ])
        });
        editorViewRef.value = new EditorView({
            state: state,
            parent: parentRef.value
        });
        editorViewRef.value.focus();
    }
    onMounted(function () {
        initEditor();
    });
    var appendText = function (_text) {
        var view = editorViewRef.value;
        var state = view.state;
        // let from =
        //   (state.selection.ranges && state.selection.ranges[0] && state.selection.ranges[0].from) ||
        //   state.doc.toString().length;
        //let transaction = state.update({ changes: { from: from, insert: _text } });
        var transaction = state.replaceSelection(_text);
        view.dispatch(transaction);
        view.focus();
    };
    var replaceText = function (_text, cursorLeft) {
        var view = editorViewRef.value;
        var state = view.state;
        var transaction = state.update({ changes: { from: 0, to: state.doc.toString().length, insert: _text } });
        view.dispatch(transaction);
        view.focus();
        //光标前移一个字符
        if (cursorLeft) {
            cursorCharLeft(view);
        }
    };
    return {
        innerValue: innerValue,
        appendText: appendText,
        replaceText: replaceText
    };
}

var commonProps = {
    value: {
        type: String
    },
    minHeight: {
        type: String,
        default: '200px'
    }
};

var script$2 = defineComponent({
    props: __assign({}, commonProps),
    setup: function (props, context) {
        var root = ref(null);
        var _a = useCodemirror(props, context, root), appendText = _a.appendText, replaceText = _a.replaceText;
        return {
            root: root,
            appendText: appendText,
            replaceText: replaceText
        };
    }
});

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$2 = script$2;

/* template */
var __vue_render__$2 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"})};
var __vue_staticRenderFns__$2 = [];

  /* style */
  const __vue_inject_styles__$2 = undefined;
  /* scoped */
  const __vue_scope_id__$2 = undefined;
  /* module identifier */
  const __vue_module_identifier__$2 = undefined;
  /* functional template */
  const __vue_is_functional_template__$2 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$2 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
    __vue_inject_styles__$2,
    __vue_script__$2,
    __vue_scope_id__$2,
    __vue_is_functional_template__$2,
    __vue_module_identifier__$2,
    false,
    undefined,
    undefined,
    undefined
  );

var script$1 = defineComponent({
    props: __assign({}, commonProps),
    setup: function (props, context) {
        var root = ref(null);
        useCodemirror(props, context, root, [xml()]);
        return {
            root: root
        };
    }
});

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"})};
var __vue_staticRenderFns__$1 = [];

  /* style */
  const __vue_inject_styles__$1 = undefined;
  /* scoped */
  const __vue_scope_id__$1 = undefined;
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    false,
    undefined,
    undefined,
    undefined
  );

var script = defineComponent({
    props: __assign({}, commonProps),
    setup: function (props, context) {
        var root = ref(null);
        useCodemirror(props, context, root, [json()]);
        return {
            root: root
        };
    }
});

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"})};
var __vue_staticRenderFns__ = [];

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

export { __vue_component__$2 as Editor, __vue_component__ as JsonEditor, __vue_component__$1 as XmlEditor, useCodemirror };

==> fuse-ui-codemirror-1.6.1.tgz: package/es/index.js <==
import { __spreadArray, __assign } from 'tslib';
import { ref, watch, onMounted, defineComponent } from '@vue/composition-api';
import _ from 'lodash';
import { EditorState, basicSetup } from '@codemirror/basic-setup';
import { EditorView, keymap } from '@codemirror/view';
import { indentWithTab, standardKeymap, cursorCharLeft } from '@codemirror/commands';
import { xml } from '@codemirror/lang-xml';
import { json } from '@codemirror/lang-json';

function useCodemirror(props, context, parentRef, extensions) {
    if (extensions === void 0) { extensions = []; }
    var innerValue = ref(props.value);
    watch(function () { return props.value; }, function () {
        if (!_.isEqual(props.value, innerValue.value)) {
            if (props.value) {
                innerValue.value = props.value;
            }
        }
    });
    watch(innerValue, function () {
        if (!_.isEqual(props.value, innerValue.value)) {
            context.emit('input', innerValue.value);
        }
    });
    var editorViewRef = ref(null);
    function initEditor() {
        var changeHandler = EditorView.updateListener.of(function (v) {
            if (v.docChanged) {
                innerValue.value = v.state.doc.toString();
            }
        });
        var minHeightStyle = EditorView.theme({
            '.cm-content, .cm-gutter': { minHeight: props.minHeight },
            '&': { border: '1px solid rgba(0, 0, 0, 0.15)' },
            '&.cm-focused': { border: '1px solid rgba(0, 0, 0, 0.24)', outline: 'none' }
        });
        var state = EditorState.create({
            doc: innerValue.value,
            extensions: __spreadArray(__spreadArray([
                basicSetup,
                EditorState.tabSize.of(2),
                keymap.of(__spreadArray([indentWithTab], standardKeymap)),
                changeHandler
            ], extensions), [
                minHeightStyle
            ])
        });
        editorViewRef.value = new EditorView({
            state: state,
            parent: parentRef.value
        });
        editorViewRef.value.focus();
    }
    onMounted(function () {
        initEditor();
    });
    var appendText = function (_text) {
        var view = editorViewRef.value;
        var state = view.state;
        // let from =
        //   (state.selection.ranges && state.selection.ranges[0] && state.selection.ranges[0].from) ||
        //   state.doc.toString().length;
        //let transaction = state.update({ changes: { from: from, insert: _text } });
        var transaction = state.replaceSelection(_text);
        view.dispatch(transaction);
        view.focus();
    };
    var replaceText = function (_text, cursorLeft) {
        var view = editorViewRef.value;
        var state = view.state;
        var transaction = state.update({ changes: { from: 0, to: state.doc.toString().length, insert: _text } });
        view.dispatch(transaction);
        view.focus();
        //光标前移一个字符
        if (cursorLeft) {
            cursorCharLeft(view);
        }
    };
    return {
        innerValue: innerValue,
        appendText: appendText,
        replaceText: replaceText
    };
}

var commonProps = {
    value: {
        type: String
    },
    minHeight: {
        type: String,
        default: '200px'
    }
};

var script$2 = defineComponent({
    props: __assign({}, commonProps),
    setup: function (props, context) {
        var root = ref(null);
        var _a = useCodemirror(props, context, root), appendText = _a.appendText, replaceText = _a.replaceText;
        return {
            root: root,
            appendText: appendText,
            replaceText: replaceText
        };
    }
});

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$2 = script$2;

/* template */
var __vue_render__$2 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"})};
var __vue_staticRenderFns__$2 = [];

  /* style */
  const __vue_inject_styles__$2 = undefined;
  /* scoped */
  const __vue_scope_id__$2 = undefined;
  /* module identifier */
  const __vue_module_identifier__$2 = undefined;
  /* functional template */
  const __vue_is_functional_template__$2 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$2 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
    __vue_inject_styles__$2,
    __vue_script__$2,
    __vue_scope_id__$2,
    __vue_is_functional_template__$2,
    __vue_module_identifier__$2,
    false,
    undefined,
    undefined,
    undefined
  );

var script$1 = defineComponent({
    props: __assign({}, commonProps),
    setup: function (props, context) {
        var root = ref(null);
        useCodemirror(props, context, root, [xml()]);
        return {
            root: root
        };
    }
});

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"})};
var __vue_staticRenderFns__$1 = [];

  /* style */
  const __vue_inject_styles__$1 = undefined;
  /* scoped */
  const __vue_scope_id__$1 = undefined;
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    false,
    undefined,
    undefined,
    undefined
  );

var script = defineComponent({
    props: __assign({}, commonProps),
    setup: function (props, context) {
        var root = ref(null);
        useCodemirror(props, context, root, [json()]);
        return {
            root: root
        };
    }
});

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"})};
var __vue_staticRenderFns__ = [];

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

export { __vue_component__$2 as Editor, __vue_component__ as JsonEditor, __vue_component__$1 as XmlEditor, useCodemirror };
